@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,9 +14,4 @@ ActivitiesManager::ActivitiesManager(QObject *parent)
 
 ActivitiesManager::~ActivitiesManager() = default;
 
-bool ActivitiesManager::enabled() const
-{
-    return Akregator::Settings::self()->plasmaActivitySupport();
-}
-
 #include "moc_activitiesmanager.cpp"
